{% load static %}

<!-- ======= Header ======= -->
<header id="header" class="fixed-top d-flex align-items-center">
  <div class="container">
    <div class="header-container d-flex align-items-center justify-content-between">
      <div class="logo">
        <!-- 로고 -->
        {% if use_logo %}
          <a href="{% url 'bethany_ds:buildup' %}" class="text-light"><img src="{% static 'img/logo.png' %}" alt="" class="img-fluid" style="height:48px;"></a>
        {% else %}
          <h1 class="text-light"><a href="{% url 'bethany_ds:buildup' %}">{{ seo.company_name }}</a></h1>
        {% endif %}
      </div>

      <nav id="navbar" class="navbar">
        <ul>
          <li><a class="nav-link scrollto active" href="#hero">Home</a></li>
          <!-- 메뉴 -->
          {% for component, _, title, is_show in components %}
            {% if is_show %}
            <li><a class="nav-link scrollto" href="#{{ component }}">{{ title }}</a></li>
            {% endif %}
          {% endfor %}
          {% for component, _, title, is_show in components %}
          {% if component == "appointment" and is_show %}
          <li><a class="getstarted scrollto" href="#contact">진료예약</a></li>
          {% endif %}
          {% endfor %}
        </ul>
        <i class="bi bi-list mobile-nav-toggle"></i>
      </nav><!-- .navbar -->
    </div><!-- End Header Container -->
  </div>
</header><!-- End Header -->
