
  <!-- ======= Footer ======= -->
  <footer id="footer">
    <div class="container d-md-flex py-4">

      <div class="me-md-auto text-center text-md-start">
        <div class="copyright">
          &copy; Copyright <a href="https://demiansoft.com" target="_blank"><strong><span>Demiansoft</span></strong></a>. All Rights Reserved
        </div>

      </div>
      <div class="social-links text-center text-md-right pt-3 pt-md-0">
      {% if social.twitter %}
      <a href="{{ social.twitter }}" class="twitter" title="{{ basic_info.clinic }} 트위터 바로가기" target="_blank"><i class="bx bxl-twitter"></i></a>
      {% endif %}
      {% if social.facebook %}
      <a href="{{ social.facebook }}" class="facebook" title="{{ basic_info.clinic }} 페이스북 바로가기" target="_blank"><i class="bx bxl-facebook"></i></a>
      {% endif %}
      {% if social.instagram %}
      <a href="{{ social.instagram }}" class="instagram" title="{{ basic_info.clinic }} 인스타그램 바로가기" target="_blank"><i class="bx bxl-instagram"></i></a>
      {% endif %}
      {% if social.youtube %}
      <a href="{{ social.youtube }}" class="youtube" title="{{ basic_info.clinic }} 유튜브 바로가기" target="_blank"><i class="bx bxl-youtube"></i></a>
      {% endif %}
      {% if social.blog %}
        <a href="{{ social.blog }}" class="blog" title="{{ basic_info.clinic }} 블로그 바로가기" target="_blank"><i class="bi bi-bootstrap-fill"></i></a>
      {% endif %}
    </div>
    </div>
  </footer><!-- End Footer -->